interface MockFunction {
    (...args: any[]): any;
    /**
     * Array of arguments passed in each call.
     */
    calls: any[][];
    /**
     * Specify the default behaviour of the mock to return a value.
     * @param value value to return by default.
     */
    returns(value: any): this;
    /**
     * Specify the next behaviour of the mock to return a value.
     * @param value value to return once.
     */
    returnsOnce(value: any): this;
    /**
     * Specify the default behaviour of the mock to throw an error.
     * @param error (optional) error to be thrown by default.
     */
    throws(error?: any): this;
    /**
     * Specify the next behaviour of the mock to throw an error.
     * @param error (optional) error to be thrown once.
     */
    throwsOnce(error?: any): this;
    /**
     * Specify the default behaviour of the mock to return a resolved promise.
     * @param value (optional) value to be contained in the promise.
     */
    resolves(value?: any): this;
    /**
     * Specify the next behaviour of the mock to return a resolved promise.
     * @param value (optional) value to be contained in the promise.
     */
    resolvesOnce(value?: any): this;
    /**
     * Specify the default behaviour of the mock to return a rejected promise.
     * @param error (optional) error to be contained in the promise.
     */
    rejects(error?: any): this;
    /**
     * Specify the next behaviour of the mock to return a rejected promise.
     * @param error (optional) error to be contained in the promise.
     */
    rejectsOnce(error?: any): this;
}
/**
 * Create a mock function that remembers calls.
 * @param implementation function to forward calls to.
 */
export declare function mockFn(implementation?: Function): MockFunction;
export declare function isMockFunction(value: unknown): value is MockFunction;
export {};
