"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AssertionError_1 = require("../AssertionError");
var utils_1 = require("../utils");
function validateSatisfy(value, negated, fn) {
    var name = fn.name || 'toSatisfy';
    var result = fn(value);
    if (result instanceof Promise) {
        return result.then(function (value) { return processResult(value, negated, name); });
    }
    return processResult(result, negated, name);
}
exports.validateSatisfy = validateSatisfy;
function processResult(result, negated, name) {
    if (isValidationResult(result)) {
        if (result.success && negated) {
            throw new AssertionError_1.AssertionError(result.negatedMessage);
        }
        else if (!result.success && !negated) {
            throw new AssertionError_1.AssertionError(result.message);
        }
    }
    else {
        if (result && negated) {
            throw new AssertionError_1.AssertionError(name + " check succeded, but was expected to fail");
        }
        else if (!result && !negated) {
            throw new AssertionError_1.AssertionError(name + " check failed");
        }
    }
}
function isValidationResult(value) {
    if (value && typeof value === 'object') {
        if (utils_1.hasOwnProperty(value, 'success') &&
            utils_1.hasOwnProperty(value, 'message') &&
            utils_1.hasOwnProperty(value, 'negatedMessage')) {
            return true;
        }
        else {
            console.warn('A custom validator returned an object that is not a validation result. ' +
                'This is equivalent to returning false from the validator and should be avoided.');
        }
    }
    return false;
}
exports.isValidationResult = isValidationResult;
